Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(408)

Unified Diff: chrome/browser/ui/tabs/tab_strip_model.h

Issue 11364196: Remove TabContents from TabStripModelObserver::ActiveTabChanged. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/gtk/tabs/tab_strip_gtk.cc ('k') | chrome/browser/ui/tabs/tab_strip_model.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/tabs/tab_strip_model.h
diff --git a/chrome/browser/ui/tabs/tab_strip_model.h b/chrome/browser/ui/tabs/tab_strip_model.h
index f988e7a611e6407682808cc5db1b35dcecd2bf87..80fb598a9fec15fea3e04c9652f6c9865d22f2f1 100644
--- a/chrome/browser/ui/tabs/tab_strip_model.h
+++ b/chrome/browser/ui/tabs/tab_strip_model.h
@@ -339,16 +339,16 @@ class TabStripModel : public content::NotificationObserver {
// TabStripModelOrderController.
void ForgetAllOpeners();
// Forgets the group affiliation of the specified TabContents. This
// should be called when a TabContents that is part of a logical group
// of tabs is moved to a new logical context by the user (e.g. by typing a new
// URL or selecting a bookmark). This also forgets the opener, which is
// considered a weaker relationship than group.
- void ForgetGroup(TabContents* contents);
+ void ForgetGroup(content::WebContents* contents);
// Returns true if the group/opener relationships present for |contents|
// should be reset when _any_ selection change occurs in the model.
- bool ShouldResetGroupOnSelect(TabContents* contents) const;
+ bool ShouldResetGroupOnSelect(content::WebContents* contents) const;
// Changes the blocked state of the tab at |index|.
void SetTabBlocked(int index, bool blocked);
@@ -544,7 +544,7 @@ class TabStripModel : public content::NotificationObserver {
void NotifyIfTabDeactivated(content::WebContents* contents);
// Notifies the observers if the active tab has changed.
- void NotifyIfActiveTabChanged(TabContents* old_contents,
+ void NotifyIfActiveTabChanged(content::WebContents* old_contents,
NotifyTypes notify_types);
// Notifies the observers if the active tab or the tab selection has changed.
« no previous file with comments | « chrome/browser/ui/gtk/tabs/tab_strip_gtk.cc ('k') | chrome/browser/ui/tabs/tab_strip_model.cc » ('j') | no next file with comments »
@@ -339,16 +339,16 @@ class TabStripModel : public content::NotificationObserver {
// TabStripModelOrderController.
void ForgetAllOpeners();
- // Forgets the group affiliation of the specified TabContents. This
- // should be called when a TabContents that is part of a logical group
+ // Forgets the group affiliation of the specified WebContents. This
+ // should be called when a WebContents that is part of a logical group
// of tabs is moved to a new logical context by the user (e.g. by typing a new
// URL or selecting a bookmark). This also forgets the opener, which is

Powered by Google App Engine
This is Rietveld 408576698